Documentation
¶
Index ¶
Constants ¶
const Dependency = "riff-invoker-node"
Dependency is a key identifying the node invoker dependency in the build plan.
const FunctionArtifact = "fn"
functionArtifact is a key identifying the path to the function entrypoint in the build plan.
const StreamingDependency = "streaming-http-adapter"
StreamingDependency is a key identifying the streaming HTTP adapter dependency.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Function ¶ added in v0.2.0
type Function struct {
// contains filtered or unexported fields
}
Function represents the function to be executed.
func NewFunction ¶ added in v0.2.0
NewFunction creates a new instance returning true if the riff-invoker-node plan exists.
func (Function) Contribute ¶ added in v0.2.0
Contributes makes the contribution to the launch layer.
type Invoker ¶ added in v0.2.0
type Invoker struct {
// contains filtered or unexported fields
}
Invoker represents the Java invoker contributed by the buildpack.
func NewInvoker ¶ added in v0.2.0
NewInvoker creates a new instance returning true if the riff-invoker-node plan exists.
func (Invoker) Contribute ¶ added in v0.2.0
Contributes makes the contribution to the launch layer.
type StreamingHTTPAdapter ¶ added in v0.2.0
type StreamingHTTPAdapter struct {
// contains filtered or unexported fields
}
StreamingHTTPAdapter represents the streaming HTTP adapter contribute by the buildpack.
func NewStreamingHTTPAdapter ¶ added in v0.2.0
func NewStreamingHTTPAdapter(build build.Build) (StreamingHTTPAdapter, error)
NewStreamingHTTPAdapter creates a new instance.
func (StreamingHTTPAdapter) Contribute ¶ added in v0.2.0
func (s StreamingHTTPAdapter) Contribute() error
Contributes makes the contribution to the launch layer.